..
      Copyright 2017 Catalyst IT Ltd
      All Rights Reserved.
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Function execution monitoring
=============================

Qinling automatically monitors functions on your behalf and records several
metrics in the database. These metrics include total requests, latency, and
error rates.

You can query metrics for function and view the execution logs by using
qinling CLI, or the Restful API. The following procedures show you how to
access metrics using these different methods.
